/*
 * Copyright (C) 2021 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.example.android.splashscreen

import androidx.test.core.app.launchActivity
import androidx.test.espresso.Espresso.onView
import androidx.test.espresso.assertion.ViewAssertions.matches
import androidx.test.espresso.matcher.ViewMatchers.isDisplayed
import androidx.test.espresso.matcher.ViewMatchers.withText
import androidx.test.ext.junit.runners.AndroidJUnit4
import androidx.test.filters.MediumTest
import org.junit.Test
import org.junit.runner.RunWith

@RunWith(AndroidJUnit4::class)
@MediumTest
class LaunchTest {

    @Test
    fun defaultActivity() {
        launchActivity<DefaultActivity>().use {
            onView(withText("Default Splash Screen")).check(matches(isDisplayed()))
        }
    }

    @Test
    fun animatedActivity() {
        launchActivity<AnimatedActivity>().use {
            onView(withText("Animated Splash Screen")).check(matches(isDisplayed()))
        }
    }

    @Test
    fun customActivity() {
        launchActivity<CustomActivity>().use {
            onView(withText("Custom Splash Screen")).check(matches(isDisplayed()))
        }
    }
}
